<?php
GFForms::include_feed_addon_framework();
class GFKlickTippManagerPremium extends GFFeedAddOn {
	protected $_version = EDD_GF_KLICK_TIPP_MANAGER_PREMIUM_VERSION;
	protected $_min_gravityforms_version = '1.9.16';
	protected $_slug = 'gfklicktippmanagerpremium';
	protected $_path = 'gravity-forms-klick-tipp-manager-premium/gravity-forms-klick-tipp-manager-premium.php';
	protected $_full_path = __FILE__;
	protected $_title = 'Gravity Forms Klick Tipp Manager - Premium';
	protected $_short_title = 'Klick-Tipp-Manager Premium';
	private static $_instance = null;
	/**
	 * Get an instance of this class.
	 *
	 * @return GFSimpleFeedAddOn
	 */
	public static function get_instance() {
		if ( self::$_instance == null ) {
			self::$_instance = new GFKlickTippManagerPremium();
		}
		return self::$_instance;
	}

	/**
	 * Plugin starting point. Handles hooks, loading of language files and PayPal delayed payment support.
	 */
	public function init() {
		parent::init();

	}

	// # SCRIPTS & STYLES -----------------------------------------------------------------------------------------------
	/**
	 * Return the scripts which should be enqueued.
	 *
	 * @return array
	 */
	public function scripts() {
		$scripts = array(
			array(
				'handle'  => 'klick_tipp_js',
				'src'     => $this->get_base_url() . '/js/admin.js',
				'version' => $this->_version,
				'deps'    => array( 'jquery' ),
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gfklicktippmanagerpremium',
					),
				),
			),
			array(
				'handle'  => 'selectWoo',
				'src'     => $this->get_base_url() . '/js/selectWoo.min.js',
				'version' => $this->_version,
				'deps'    => array( 'jquery' ),
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gfklicktippmanagerpremium',
					),
				),
			),
			array(
				'handle'  => 'klick_tipp_admin_settings',
				'src'     => $this->get_base_url() . '/js/admin-settings.js',
				'version' => $this->_version,
				'deps'    => array( 'jquery' ),
				'enqueue' => array(
					array(
						'admin_page' => array(  'plugin_settings'  )
					),
				),
			),
		);
		return array_merge( parent::scripts(), $scripts );
	}

	public function styles() {
		$styles = array(
			array(
				'handle'  => 'selectWoo',
				'src'     => $this->get_base_url() . '/css/selectWoo.min.css',
				'version' => $this->_version,
				'enqueue' => array(
					array(
						'admin_page' => array( 'form_settings' ),
						'tab'        => 'gfklicktippmanagerpremium',
					),
				),
			),
		);
		return array_merge( parent::styles(), $styles );
	}

	// # FEED PROCESSING -----------------------------------------------------------------------------------------------
	/**
	 * Process the feed e.g. subscribe the user to a list.
	 *
	 *
	 * @param array   $feed  The feed object to be processed.
	 * @param array   $entry The entry object currently being processed.
	 * @param array   $form  The form object currently being processed.
	 * @return bool|void
	 */
	public function process_feed( $feed, $entry, $form ) {
		$email = '';
		$smsnumber = '';
		$custom_fields = array();
		$tags_to_add = array();
		$tags_to_remove = array();
		$send_empty_values = $feed['meta']['send_empty_values'];

		// Retrieve the name => value pairs for all fields mapped in the 'mappedFields' field map.
		$field_map = $this->get_field_map_fields( $feed, 'mappedFields' );
		foreach ( $field_map as $name => $field_id ) {
			// If no field is mapped, skip it.
			if ( rgblank( $field_id ) ) {
				continue;
			}
			$value = $this->get_field_value( $form, $entry, $field_id );
			// If field value is empty and we are not overriding empty fields, skip it.
			if ( empty( $value ) && $send_empty_values != 1 ) {
				continue;
			}

			// check & send date in correct format
			$field = RGFormsModel::get_field( $form, $field_id );
			if (  is_object( $field ) ) {
				if ( $field->type == 'date' || $field->type == 'simple' ) {
					$time = $value;
					$date = new DateTime( $time, new DateTimeZone( 'Europe/Berlin' ) ); // KT's expected timezone
					$date->setTimezone( new DateTimeZone( 'UTC' ) );
					$value = $date->format( "U" );
				} else if ( $field->type == 'time' ) {
					$value = date( 'U', strtotime( '1970-01-01 ' . $value ) );
				}
			}

			switch ( $name ) {
			case 'email':
				$email =  $value;
				break;
			case 'smsnumber':
				$smsnumber =  $value;
				break;
			default:
				$custom_fields[$name] = $value;
				break;
			}
		}

		$list_id = $feed['meta']['list_id'];
		GF_Ktm_Logs()->log( '============= SENDING DATA FOR ENTRY ID: ' . $entry['id'] . ' === ' . date( 'd/M/Y' ) . ' ============= ' );
		GF_Ktm_Logs()->log( 'List ID => ' . $list_id . PHP_EOL . 'Email ID => ' . $email . PHP_EOL . 'Other Fields => ' . print_r( $custom_fields, TRUE  ) );

		//print( '<pre>' . print_r( $feed, true ) . '</pre>' );

		if ( ! empty ( $email ) ) {
			$settings = $this->get_plugin_settings();
			$connector = new KlicktippConnector();
			$logged_in = $connector->login( $settings['username'], $settings['password'] );
			//create new user
			$subscriber = $connector->subscribe( $email, $list_id, 0, $custom_fields, $smsnumber );
			//if ( true ) {
			if ( $subscriber ) {
				GF_Ktm_Logs()->log( '- Suceessfully added contact ' . PHP_EOL .  'Contact Details => ' . PHP_EOL . print_r( $subscriber, TRUE ) );

				// Save contact id to entry meta
				gform_update_meta( $entry['id'], 'ktm_contact_id', $subscriber->id );
				/**  --- get tags to add --  **/
				if ( ! empty( $feed['meta']['add_tags'] ) ) {
					$tags_to_add =  $feed['meta']['add_tags'];
				}

				// check conditional tags
				$conditional_tags_enabled = isset( $feed['meta']['condition_add_tags_enabled'] )?$feed['meta']['condition_add_tags_enabled']: false;
				if ( $conditional_tags_enabled ) {
					if ( ! empty( $feed['meta']['condition_add_tags_object']['rules'] ) ) {
						$conditional_tags = $this->get_conditional_tags_for_feed( $feed['meta']['condition_add_tags_object']['rules'], $form, $entry );
						if ( ! empty( $conditional_tags ) ) {
							$tags_to_add = array_merge( $tags_to_add, $conditional_tags );
						}
					}
				}
				if ( ! empty( $tags_to_add ) ) {
					$sub  = $connector->tag( $email, $tags_to_add );
				}

				/**  --- get tags to remove --  **/
				if ( ! empty( $feed['meta']['remove_tags'] ) ) {
					$tags_to_remove =  $feed['meta']['remove_tags'];
				}

				// check conditional tags
				$conditional_tags_enabled = isset( $feed['meta']['condition_remove_tags_enabled'] )?$feed['meta']['condition_remove_tags_enabled']: false;
				if ( $conditional_tags_enabled ) {
					if ( ! empty( $feed['meta']['condition_remove_tags_object']['rules'] ) ) {
						$conditional_tags = $this->get_conditional_tags_for_feed( $feed['meta']['condition_remove_tags_object']['rules'], $form, $entry );
						if ( ! empty( $conditional_tags ) ) {
							$tags_to_remove = array_merge( $tags_to_remove, $conditional_tags );
						}
					}
				}
				if ( ! empty( $tags_to_remove ) ) {
					foreach ( $tags_to_remove as $remove_tag_id ) {
						$sub  = $connector->untag( $email, $remove_tag_id );
					}
				}
				// print_r( array_unique($tags_to_add) );print_r( array_unique($tags_to_remove) );die;
				$connector->logout();
			} else {
				$error = $connector->get_last_error();
				GF_Ktm_Logs()->log( '- Error Occurred:' . PHP_EOL . $error . PHP_EOL );
				// Save error to entry meta
				gform_update_meta( $entry['id'], 'ktm_error', $error );
				$connector->logout();
			}
		}
	}

	// # ADMIN FUNCTIONS -----------------------------------------------------------------------------------------------

	/**
	 * Configures the settings which should be rendered on the add-on settings tab.
	 *
	 * @return array
	 */
	public function plugin_settings_fields() {

		return array(
			array(
				'title'  => esc_html__( 'Klick-Tipp Add-on-Einstellung', 'simplefeedaddon' ),
				'fields' => array(
					array(
						'name'    => 'license_key',
						'tooltip' => esc_html__( 'Bitte fügen Sie hier Ihren Lizenz-Schlüssel ein.', 'simplefeedaddon' ),
						'label'   => esc_html__( 'Lizenz-Schlüssel', 'simplefeedaddon' ),
						'type'    => 'text',
						'class'   => 'medium',
						'input_type'=> 'password',
						'style' =>'width:350px',
						'validation_callback' => array( $this, 'license_validation' ),
						'feedback_callback'   => array( $this, 'license_feedback' ),
						'error_message'       => esc_html__( 'Invalid license', 'simpleaddon' ),
						'placeholder'=>'e.g 9eb089d6e6472b0ad85d987a36',
						'after_input'=>'<br/> <i>Bitte fügen Sie hier Ihren Lizenz-Schlüssel ein.</i>'
						//'after_input'=>$license_text.'<br/> <i>Add license key for plugin support & updates</i>'
					),
					array(
						'name'    => 'username',
						'tooltip' => esc_html__( 'Bitte fügen Sie hier Ihren Klick-Tipp-Benutzernamen ein.', 'simplefeedaddon' ),
						'label'   => esc_html__( 'Klick-Tipp Benutzername', 'simplefeedaddon' ),
						'placeholder'=>'e.g john',
						'type'    => 'text',
						'class'   => 'medium',
						'after_input'=>'<br/> <i>Bitte fügen Sie hier Ihren Klick-Tipp-Benutzernamen ein.</i>'
					),

					array(
						'name'    => 'password',
						'tooltip' => esc_html__( 'Bitte fügen Sie hier Ihr Klick-Tipp-Passwort ein.', 'simplefeedaddon' ),
						'label'   => esc_html__( 'Klick-Tipp Passwort', 'simplefeedaddon' ),
						'type'    => 'text',
						'input_type'=> 'password',
						'placeholder' => '',
						'class'   => 'medium',
						'after_input'=>'<br/> <i>Bitte fügen Sie hier Ihr Klick-Tipp-Passwort ein.</i> '
					),
					array(
						'name'    => 'enable_log',
						'tooltip' => esc_html__( 'Error Logging.', 'simplefeedaddon' ),
						'label'   => esc_html__( 'Error Logging', 'simplefeedaddon' ),
						'type'    => 'checkbox',
						'choices' => array(
							array(
								'label'         => esc_html__( 'Enable ', 'simplefeedaddon' ),
								'name'          => 'enable_log',
								'tooltip'       => esc_html__( 'Check it to enable logging of debug messages', 'simplefeedaddon' ),
							),

						),
						'after_input'=>'<br/> <i>Check it to enble logging.</i> '
					),
					array(
						'name'    => 'clear_log',
						'label'   => esc_html__( '', 'simplefeedaddon' ),
						'type'    => 'text_clear_log',
						'placeholder' => '',
						'class'   => 'medium',
					),
				),
			),
		);
	}
	/**
	 * Configures the settings which should be rendered on the feed edit page in the Form Settings > Simple Feed Add-On area.
	 *
	 * @return array
	 */
	public function feed_settings_fields() {

		$settings = $this->get_plugin_settings();

		$connector = new KlicktippConnector();
		$logged_in = $connector->login( $settings['username'], $settings['password'] );
		//$test = $connector->subscriber_get( 25844570 );
		//echo '<pre>';print_r($test); die;
		$message = '';
		if ( ! $logged_in ) {
			$message =   $connector->get_last_error();
		}else {
			$fields = $connector->field_index();

			if ( ! $fields ) {
				$message =  $connector->get_last_error();
			}
			$tags = $connector->tag_index();
			if ( ! $tags ) {
				$message =  $connector->get_last_error();
			}

			$subscription_processes = $connector->subscription_process_index();
			if ( ! $subscription_processes ) {
				$message =  $connector->get_last_error();
			}
			$connector->logout();
		}

		$license_key = $this->get_plugin_setting( 'license_key' );
		$valid_license = $this->license_feedback( $license_key, 'null' );
		if ( ! $valid_license ) {
			$message = 'Please enter a valid license key to use the plugin';
		}
		$message = apply_filters( 'gf_klick_tipp_connect_error_message', $message );
		if ( $message != '' ) {
			return array(
				array(
					'title'  => $message,
					'fields' => array(

					)
				)
			);
		}
		$this->upgrade_tag_fields();
		$feed_fields = array(
			array(
				'name'       => 'email',
				'label'      => esc_html__( 'Email', 'simplefeedaddon' ),
				'required'   => 1,
				'field_type' => array( 'email', 'hidden' ),
				'tooltip' => esc_html__( 'User E-Mail die übergeben werden soll. Pflichfeld.', 'simplefeedaddon' ),
			),
			array(
				'name'       => 'smsnumber',
				'label'      => esc_html__( 'SMS-Mobilnummmer', 'simplefeedaddon' ),
				'required'   => 0,
				//'tooltip' => esc_html__( 'User E-Mail die übergeben werden soll. Pflichfeld.', 'simplefeedaddon' ),
			),
		);


		// fields
		foreach ( $fields as $fieldkey=>$field ) {
			$feed_fields[] =  array(
				'name'     => trim( $fieldkey ),
				'label'    => esc_html__( $field, 'simplefeedaddon' ),
				'required' => 0,
			);
		}

		// double opt in processes
		$dops = array();
		foreach ( $subscription_processes as $subscription_key=>$dop ) {
			$dops[] =  array(
				'value'     => $subscription_key ,
				'label'    => esc_html__( $dop, 'simplefeedaddon' ),

			);
		}
		//tags
		$tag_fields = array();

		$tag_options = array();

		foreach ( $tags as $tagkey=>$tag ) {
			$tag_fields[] =  array( 'name'     => $tagkey , 'label'    => esc_html__( $tag, 'simplefeedaddon' ) );
			$tag_options[] =  array( 'value'     =>  $tagkey , 'label'    => esc_html__( $tag, 'simplefeedaddon' ) );
		}

		$this->_tag_choices = $tag_fields;

		return array( array(
				'title'  => esc_html__( 'Klick Tipp Feed Einstellungen', 'simplefeedaddon' ),
				'fields' => array(
					array(
						'label'   => esc_html__( 'Feed Name', 'simplefeedaddon' ),
						'type'    => 'text',
						'name'    => 'feedName',
						'class'   => 'medium',
					),
					array(
						'label'   => esc_html__( 'Double-Optin-Prozess', 'simplefeedaddon' ),
						'type'    => 'select',
						'name'    => 'list_id',
						'choices' => $dops,
					),
					array(
						'name'      => 'mappedFields',
						'label'     => esc_html__( 'Felder zuordnen', 'simplefeedaddon' ),
						'type'      => 'field_map',
						'field_map' => $feed_fields,
					),
					array(
						'label'   => 'Leere Felder aktualisieren',
						'type'    => 'checkbox',
						'name'    => 'send_empty_values',
						'choices' => array(
							array(
								'label' => 'Aktivieren',
								'name'  => 'send_empty_values'
							)
						)
					),
					array(
						'label'   => 'Zuweisung von Tags pro Formular',
						'type'   => 'select',
						'name'  => 'add_tags[]',
						'choices' => $tag_options,
						'class'   => 'ktm-select',
						'multiple' => 'multiple',
					),
					array(
						'label' => esc_html__( 'Bedingte Zuweisung von Tags', 'simpleaddon' ),
						'type'  => 'field_condition_tags',
						'name'  => 'condition_add_tags',
					),
					array(
						'label'   => 'Entfernung von Tags pro Formular',
						'type'   => 'select',
						'name'  => 'remove_tags[]',
						'choices' => $tag_options,
						'class'   => 'ktm-select',
						'multiple' => 'multiple',
					),
					array(
						'label' => esc_html__( 'Bedingte Entfernung von Tags', 'simpleaddon' ),
						'type'  => 'field_condition_tags',
						'name'  => 'condition_remove_tags',
					),
					array(
						'name'           => 'condition',
						'label'          => esc_html__( 'Feed Bedingung', 'simplefeedaddon' ),
						'type'           => 'feed_condition',
						'checkbox_label' => esc_html__( 'Aktivieren', 'simplefeedaddon' ),
						'instructions'   => esc_html__( 'Diesen Feed ausführen wenn', 'simplefeedaddon' ),
					),
				),
			), );
	}


	/***
	 * Renders and initializes a checkbox field or a collection of checkbox fields based on the $field array
	 *
	 * @param array $field - Field array containing the configuration options of this field
	 * @param bool  $echo  = true - true to echo the output to the screen, false to simply return the contents as a string
	 *
	 * @return string The HTML for the field
	 */
	// public function settings_checkbox( $field, $echo = true ) {

	// 	$field['type'] = 'checkbox'; //making sure type is set to checkbox

	// 	$field_attributes   = $this->get_field_attributes( $field, array() );
	// 	$have_icon          = $this->choices_have_icon( rgar( $field, 'choices' ) );
	// 	$horizontal         = rgar( $field, 'horizontal' ) || $have_icon ? ' gaddon-setting-inline' : '';

	// 	$html = '';
	// 	if (  $field['name'] == 'add_tags' || $field['name'] == 'remove_tags' ) {
	// 		$html = '<div style=" height: 400px;overflow-y: scroll;max-width: 450px;" class="klick-tipp-tags-cont">';
	// 	}
	// 	$default_choice_attributes = array( 'onclick' => 'jQuery(this).siblings("input[type=hidden]").val(jQuery(this).prop("checked") ? 1 : 0);', 'onkeypress' => 'jQuery(this).siblings("input[type=hidden]").val(jQuery(this).prop("checked") ? 1 : 0);' );
	// 	$is_first_choice = true;
	// 	if ( is_array( $field['choices'] ) ) {
	// 		foreach ( $field['choices'] as $choice ) {
	// 			$choice['id']      = sanitize_title( $choice['name'] );
	// 			$choice_attributes = $this->get_choice_attributes( $choice, $field_attributes, $default_choice_attributes );
	// 			$value             = $this->get_setting( $choice['name'], rgar( $choice, 'default_value' ) );
	// 			$tooltip           = $this->maybe_get_tooltip( $choice );

	// 			//displaying error message after first checkbox item
	// 			$error_icon = '';
	// 			if ( $is_first_choice ) {
	// 				$error_icon = $this->field_failed_validation( $field ) ? $this->get_error_icon( $field ) : '';
	// 			}

	// 			// Add icon to choice if choices have icon
	// 			if ( $have_icon ) {
	// 				$choice['icon'] = rgar( $choice, 'icon' ) ? $choice['icon'] : 'fa-cog';
	// 			}

	// 			$html .= $this->checkbox_item( $choice, $horizontal, $choice_attributes, $value, $tooltip, $error_icon );

	// 			$is_first_choice = false;
	// 		}
	// 	}
	// 	if (  $field['name'] == 'add_tags' || $field['name'] == 'remove_tags' ) {
	// 		$html .= '</div>';
	// 	}

	// 	if ( $echo ) {
	// 		echo $html;
	// 	}

	// 	return $html;
	// }

	public function settings_field_condition_tags( $field, $echo = true ) {

		// Get the setting name.
		$name = $field['name'];

		// Define the properties for the checkbox to be used to enable/disable access to the simple condition settings.
		$checkbox_field = array(
			'name'    => $name,
			'type'    => 'checkbox',
			'choices' => array(
				array(
					'label' => esc_html__( 'Aktivieren', 'simpleaddon' ),
					'name'  => $name . '_enabled',
				),
			),
			'onclick' => "if(this.checked){jQuery('#{$name}_condition_container').show();} else{jQuery('#{$name}_condition_container').hide();}",
		);

		// Determine if the checkbox is checked, if not the simple condition settings should be hidden.
		$is_enabled      = $this->get_setting( $name . '_enabled' ) == '1';
		$container_style = ! $is_enabled ? "style='display:none;'" : '';

		// Put together the field markup.
		$str = sprintf( "%s<div class='gform-settings-field__conditional-logic condition_tags_logic_cont' id='%s_condition_container' %s>%s</div>",
			$this->settings_checkbox( $checkbox_field, false ),
			$name,
			$container_style,
			$this->tags_condition( $name )
		);

		echo $str;
	}


	public function tags_condition( $name ) {
		$select_tags_label = 'Tags zuweisen';
		if ( $name == 'condition_remove_tags' ) {
			$select_tags_label = 'Tags entfernen';
		}

		$operator_choices = array(
			array(
				'value' => 'is',
				'label' => esc_html__( 'ist gleich', 'gravityforms' ),
			),
			array(
				'value' => 'isnot',
				'label' => esc_html__( 'ist nicht', 'gravityforms' ),
			),
			array(
				'value' => '>',
				'label' => esc_html__( 'größer als', 'gravityforms' ),
			),
			array(
				'value' => '<',
				'label' => esc_html__( 'weniger als', 'gravityforms' ),
			),
			array(
				'value' => 'contains',
				'label' => esc_html__( 'enthält', 'gravityforms' ),
			),
			array(
				'value' => 'starts_with',
				'label' => esc_html__( 'beginnt mit', 'gravityforms' ),
			),
			array(
				'value' => 'ends_with',
				'label' => esc_html__( 'endet mit', 'gravityforms' ),
			),
		);
		$conditional_fields = $this->get_conditional_logic_fields();
		$obj_value = $this->get_setting( $name . "_object" );
		$inp_value = '';
		if ( ! empty( $obj_value ) ) {
			$inp_value = json_encode( $obj_value );
		}
		if(  GFForms::$version >= '2.5'){
			$input_name_prefix= '_gform_setting';
		}else{
			$input_name_prefix= '_gaddon_setting';
		}

		$str = '<input name="'.$input_name_prefix.'_' . $name . '_object" value=\'' . $inp_value . '\' type="hidden" id="'.$input_name_prefix.'_' . $name . '_object">';

		if ( ! empty( $obj_value ) && is_array( $obj_value ) ) {
			$i = 1;
			foreach ( $obj_value['rules'] as $rule ) {
				$form   = $this->get_current_form();
				$field = RGFormsModel::get_field( $form, $rule['field_id'] );
				// echo '<pre>';print_r($field->choices); die;
				$str .= '<div class="tags_condition_fields_rule">';
				$str .= '<br/>Wenn diese Bedingungen erfüllt sind:<br/>';
				//echo '<pre>'; print_r($conditional_fields); die;
				$field_options = $this->get_select_options( $conditional_fields, $rule['field_id'] );
				$str .= '<select style="max-width:400px" class="field_list">' . $field_options . '</select>';

				$operator_options = $this->get_select_options( $operator_choices, $rule['operator'] );
				$str .= '<select style="max-width:400px" class="operator_list">' . $operator_options . '</select>';

				if ( $field->type == 'select' ||  $field->type == 'radio' ||  $field->type == 'checkbox' ) {
					$rule_value_choices = array();
					foreach ( $field->choices as $choice ) {
						$rule_value_choices[] = array(
							'value' => $choice['value'],
							'label' =>  $choice['text'],
						);
					}

					$rule_options = $this->get_select_options( $rule_value_choices, $rule['cond_val'] );
					$str .= '<select  class="cond_val">' . $rule_options . '</select>';
				}else {
					$str .= '<input type="text" value="' . $rule['cond_val'] . '" class="cond_val gfield_rule_select gfield_rule_input" placeholder="Wert eingeben">';
				}

				$str .= '<a class="add_field_choice add_tag_rule_row"  title="add another rule" ><i class="gficon-add"></i></a>';
				if ( $i == 1 ) {
					if ( count( $obj_value['rules'] ) > 1  ) {
						$str .= '<a class="add_field_choice remove_tag_rule_row"  title="add another rule" ><i class="gficon-subtract"></i></a>';
					}
				} else {
					$str .= '<a class="add_field_choice remove_tag_rule_row"  title="add another rule" ><i class="gficon-subtract"></i></a>';
				}
				$str .= '<div style="margin-top:10px;margin-bottom:10px">' . $select_tags_label . '</div>';

				$str .= '<select multiple class="tags_dropdown"> ';
				$selected_tags = $rule['tags'];
				$selected_tags_arr =  explode( ',', $selected_tags );
				foreach ( $this->_tag_choices as $tag ) {
					$selected = '';
					if ( in_array( $tag['name'], $selected_tags_arr ) ) {
						$selected = 'selected="selected"';
					}
					$str .= '<option ' . $selected . ' value="' . $tag['name'] . '">' . $tag['label'] . '</option>';
				}
				$str .= '</select>';

				$str .= '</div>';
				$i++;
			}

		}else {
			$str .= '<div class="tags_condition_fields_rule">';
			$str .= '<br/>Wenn diese Bedingungen erfüllt sind:<br/>';
			//echo '<pre>'; print_r($conditional_fields); die;
			$field_options = $this->get_select_options( $conditional_fields, null );
			$str .= '<select style="max-width:400px" class="field_list">' . $field_options . '</select>';

			$operator_options =  $this->get_select_options( $operator_choices, null );
			$str .= '<select style="max-width:400px" class="operator_list">' . $operator_options . '</select>';

			$str .= '<input type="text" value="" class="cond_val gfield_rule_select gfield_rule_input" placeholder="Wert eingeben">';

			$str .= '<a class="add_field_choice add_tag_rule_row"  title="add another rule" ><i class="gficon-add"></i></a>';

			$str .= '<div style="margin-top:10px;margin-bottom:10px">' . $select_tags_label . '</div>';

			$str .= '<select multiple class="tags_dropdown"> ';

			foreach ( $this->_tag_choices as $tag ) {

				$str .= '<option  value="' . $tag['name'] . '">' . $tag['label'] . '</option>';
			}
			$str .= '</select>';

			$str .= '</div>';
		}

		return $str;
	}

	public function get_conditional_logic_fields() {
		$form   = $this->get_current_form();
		$fields = array();
		foreach ( $form['fields'] as $field ) {
			if ( $field->is_conditional_logic_supported() ) {
				$inputs = $field->get_entry_inputs();

				if ( $inputs  && $field->type != 'checkbox' ) {
					$choices = array();

					foreach ( $inputs as $input ) {
						if ( rgar( $input, 'isHidden' ) ) {
							continue;
						}
						$choices[] = array(
							'value' => $input['id'],
							'label' => GFCommon::get_label( $field, $input['id'], true )
						);
					}

					if ( ! empty( $choices ) ) {
						$fields[] = array( 'choices' => $choices, 'label' => GFCommon::get_label( $field ) );
					}

				} else {
					$fields[] = array( 'value' => $field->id, 'label' => GFCommon::get_label( $field ) );
				}

			}
		}
		return $fields;
	}

	public function get_conditional_tags_for_feed( $rules, $form, $entry ) {
		$tags = array();
		foreach ( $rules as $rule ) {
			// Build the logic array to be used by Gravity Forms when evaluating the rules.
			$logic = array(
				'logicType' => 'all',
				'rules'     => array(
					array(
						'fieldId'  => $rule['field_id'],
						'operator' => $rule['operator'],
						'value'    => $rule['cond_val'],
					),
				)
			);
			$condition_met = GFCommon::evaluate_conditional_logic( $logic, $form, $entry );

			if ( $condition_met ) {
				$tags_string = $rule['tags'];
				if ( ! empty( $tags_string ) ) {
					$tags_array = explode( ',', $tags_string );
					$tags = array_merge( $tags, $tags_array );
				}
			}
		}
		return $tags;
	}

	// change field label in field mapping area
	public function field_map_title() {
		return esc_html__( 'Klick-Tipp Felder', 'gravityforms' );
	}

	// chnage Add New feed button label
	public function feed_list_title() {
		if ( ! $this->can_create_feed() ) {
			return sprintf( __( '%s Feeds', 'gravityforms' ), $this->get_short_title() );
		}

		$url = add_query_arg( array( 'fid' => '0' ) );
		$url = esc_url( $url );
		return sprintf( esc_html__( '%s Feeds', 'gravityforms' ), $this->get_short_title() ) . " <a class='add-new-h2' href='{$url}'>" . esc_html__( 'Neuen Feed erstellen' , 'gravityforms' ) . '</a>';
	}

	// function checkbox_input_enable_log( $choice, $attributes, $value, $tooltip ) {
	// 	$icon_tag = '';

	// 	if ( rgar( $choice, 'icon' ) ) {

	// 		/* Get the defined icon. */
	// 		$icon = rgar( $choice, 'icon' ) ? $choice['icon'] : 'fa-cog';

	// 		/* Set icon tag based on icon type. */
	// 		if ( filter_var( $icon, FILTER_VALIDATE_URL ) ) {
	// 			$icon_tag = '<img src="' . esc_attr( $icon ) . '" />';
	// 		} else {
	// 			$icon_tag = '<i class="fa ' . esc_attr( $icon ) . '"></i>';
	// 		}

	// 		$icon_tag .= '<br />';

	// 	}

	// 	$markup  = '<input type = "checkbox" ' . implode( ' ', $attributes ) . ' ' . checked( $value, '1', false ) . ' />';
	// 	$markup .= '<label for="' . esc_attr( $choice['id'] ) . '"><span>' . $icon_tag . esc_html( $choice['label'] ) . $tooltip . '</span></label>';
	// 	$markup .= '&nbsp;&nbsp;&nbsp;<a target="_blank" href="' . GF_KLICK_TIPP_MANAGER_PREMIUM_PLUGIN_URL . '/logs/logs.php">View Log</a>';
	// 	$markup .= '&nbsp;&nbsp;&nbsp;<a id="clear-ktm-logfile" href="#">Clear Log</a> <span id="ktm-clearing-cache" style="display:none">Clearing...</span>';

	// 	return $markup;
	// }
	function settings_text_clear_log(){
		$markup = '<br/><a target="_blank" href="' . GF_KLICK_TIPP_MANAGER_PREMIUM_PLUGIN_URL . '/logs/logs.php">View Log</a>';
		$markup .= '&nbsp;&nbsp;&nbsp;<a id="clear-ktm-logfile" href="#">Clear Log</a> <span id="ktm-clearing-cache" style="display:none">Clearing...</span>';
		echo $markup;
	}

	/**
	 * Determine if the license key is valid so the appropriate icon can be displayed next to the field.
	 *
	 *
	 * @param string  $value The current value of the license_key field.
	 * @param array   $field The field properties.
	 * @return bool|null
	 */
	public function license_feedback( $value, $field ) {
		if ( empty( $value ) ) {
			return null;
		}

		// Send the remote request to check the license is valid
		$license_data = $this->perform_edd_license_request( 'check_license', $value );

		$valid = null;
		if ( empty( $license_data ) || $license_data->license == 'invalid' ) {
			$valid = false;
		} elseif ( $license_data->license == 'valid' ) {
			$valid = true;
		}

		return $valid;
	}

	/**
	 * Handle license key activation or deactivation.
	 *
	 * @param array   $field         The field properties.
	 * @param string  $field_setting The submitted value of the license_key field.
	 */
	public function license_validation( $field, $field_setting ) {
		$old_license = $this->get_plugin_setting( 'license_key' );

		if ( $old_license && $field_setting != $old_license ) {
			// Send the remote request to deactivate the old license
			$this->perform_edd_license_request( 'deactivate_license', $old_license );
		}

		if ( ! empty( $field_setting ) ) {
			// Send the remote request to activate the new license
			$this->perform_edd_license_request( 'activate_license', $field_setting );
		}
	}

	/**
	 * Send a request to the EDD store url.
	 *
	 *
	 * @param string  $edd_action The action to perform (check_license, activate_license or deactivate_license).
	 * @param string  $license    The license key.
	 * @return object
	 */
	public function perform_edd_license_request( $edd_action, $license ) {
		// Prepare the request arguments
		$args = array(
			'timeout'   => 10,
			'sslverify' => false,
			'body'      => array(
				'edd_action' => $edd_action,
				'license'    => trim( $license ),
				'item_id'  => urlencode( EDD_GF_KLICK_TIPP_MANAGER_PREMIUM_ITEM_ID ),
				'url'        => home_url(),
			),
		);

		// Send the remote request
		$response = wp_remote_post( EDD_GF_KLICK_TIPP_MANAGER_PREMIUM_STORE_URL, $args );

		return json_decode( wp_remote_retrieve_body( $response ) );
	}

	/**
	 * Enable feed duplication.
	 *
	 * @access public
	 * @param int|array $feed_id The ID of the feed to be duplicated or the feed object when duplicating a form.
	 * @return bool
	 */
	public function can_duplicate_feed( $feed_id ) {

		return true;

	}

	/**
	 * Configures which columns should be displayed on the feed list page.
	 *
	 * @return array
	 */
	public function feed_list_columns() {
		return array(
			'feedName'  => esc_html__( 'Name', 'simplefeedaddon' ),
		);
	}
	/**
	 * Prevent feeds being listed or created if an api key isn't valid.
	 *
	 * @return bool
	 */
	public function can_create_feed() {
		// Get the plugin settings.
		$settings = $this->get_plugin_settings();
		// Access a specific setting e.g. an api key
		$key = rgar( $settings, 'apiKey' );
		return true;
	}
	function upgrade_tag_fields() {
		$tags_to_add = array();
		$tags_to_remove = array();
		$current_feed_setting = $this->get_current_feed();
		if ( ! empty( $current_feed_setting['meta'] ) ) {
			foreach ( $current_feed_setting['meta'] as $key => $value ) {
				if ( ( strpos( $key, 'add_tag_' ) !== false ) &&  $value == '1' ) {
					$tags_to_add[] = str_replace( 'add_tag_', '', $key );
				}
				if ( ( strpos( $key, 'remove_tag_' ) !== false ) &&  $value == '1' ) {
					$tags_to_remove[] = str_replace( 'remove_tag_', '', $key );
				}
			}
		}

		if ( ! empty( $tags_to_add ) ) {
			if ( ! isset( $current_feed_setting['meta']['add_tags'] ) ) {
				$current_feed_setting['meta']['add_tags'] = $tags_to_add;
			}
		}
		if ( ! empty( $tags_to_remove ) ) {
			if ( ! isset( $current_feed_setting['meta']['remove_tags'] ) ) {
				$current_feed_setting['meta']['remove_tags'] = $tags_to_remove;
			}
		}
		if ( ! empty( $tags_to_add ) || ! empty( $tags_to_remove ) ) {
			$this->update_feed_meta( $current_feed_setting['id'], $current_feed_setting['meta'] );
		}
	}
}
